@@ -3,6 +3,7 @@
 install_dir=""
 themes_dir=""
 executable=""
+version=""
 
 error() {
     printf "\e[31m$1\e[0m\n"
@@ -21,15 +22,16 @@ help() {
     # Display Help
     echo "Install script for Oh My Posh"
     echo
-    echo "Syntax: install.sh [-h|d|t]"
+    echo "Syntax: install.sh [-h] [-d <dir>] [-t <dir>] [-v <ver>]"
     echo "options:"
     echo "-h     Print this help."
     echo "-d     Specify the installation directory. Defaults to $HOME/bin, $HOME/.local/bin or the directory where oh-my-posh is installed."
     echo "-t     Specify the themes installation directory. Defaults to the oh-my-posh cache directory."
+    echo "-v     Version to download, defaults to latest"
     echo
 }
 
-while getopts ":hd:t:" option; do
+while getopts ":hd:t:v:" option; do
    case $option in
       h) # display Help
          help
@@ -38,13 +40,15 @@ while getopts ":hd:t:" option; do
          install_dir=${OPTARG};;
       t) # themes directory
          themes_dir=${OPTARG};;
+      v) # version
+         version=${OPTARG};;
      \?) # Invalid option
          echo "Invalid option command line option. Use -h for help."
          exit 1
    esac
 done
 
-SUPPORTED_TARGETS="linux-386 linux-amd64 linux-arm linux-arm64 darwin-amd64 darwin-arm64 freebsd-386 freebsd-amd64 freebsd-arm freebsd-arm64"
+SUPPORTED_TARGETS="linux-amd64 linux-arm linux-arm64 darwin-amd64 darwin-arm64 freebsd-amd64 freebsd-arm freebsd-arm64"
 
 validate_dependency() {
     if ! command -v $1 >/dev/null; then
@@ -151,7 +155,7 @@ install_themes() {
 
     zip_file="${cache_dir}/themes.zip"
 
-    url="https://github.com/JanDeDobbeleer/oh-my-posh/releases/latest/download/themes.zip"
+    url="https://cdn.ohmyposh.dev/releases/latest/themes.zip"
 
     http_response=$(curl -s -f -L $url -o $zip_file -w "%{http_code}")
 
@@ -187,7 +191,10 @@ install() {
     info "\nℹ️  Installing oh-my-posh for ${target} in ${install_dir}"
 
     executable=${install_dir}/oh-my-posh
-    url=https://github.com/JanDeDobbeleer/oh-my-posh/releases/latest/download/posh-${target}
+    url=https://cdn.ohmyposh.dev/releases/latest/posh-${target}
+    if [ "$version" ]; then
+      url=https://cdn.ohmyposh.dev/releases/${version}/posh-${target}
+    fi
 
     info "⬇️  Downloading oh-my-posh from ${url}"
 
@@ -217,7 +224,6 @@ detect_arch() {
     armv*) arch="arm" ;;
     arm64) arch="arm64" ;;
     aarch64) arch="arm64" ;;
-    i686) arch="386" ;;
   esac
 
   if [ "${arch}" = "arm64" ] && [ "$(getconf LONG_BIT)" -eq 32 ]; then
